@@ -59,6 +59,19 @@ class Text(BaseWidget["wx.StaticText"]):
         Args:
             text:
             font_size: Font size ratio.
+            wrap: apply text wrapping.
+
+        "normal" text wrappig is not working properly. AFter calling ui_item.Wrap(),
+        the text gets extra line breaks where need. If the item is then sized bigger
+        the line breaks persist, making the text area too narrow. To overcome this
+        you need to `ui_item.SetLabel` again to set the text and after that call
+        `ui_item.Wrap()` again. This makes the parent container resize twice: Once
+        with the full width text after `SetLabel` and once more after `Wrap` this makes
+        the screen very "nervous" and sometimes doesn't scale well at all.
+
+        The workaround for this is to use an intermediate ClientDC instance which mimics
+        the statictext box and returns a wrapped string. This string is then used once
+        in the `SetLabel` method.
         """
         value_binding = (
             OneWayBindable(binding, self._set_ui_value) if binding is not None else None
@@ -94,8 +107,6 @@ class Text(BaseWidget["wx.StaticText"]):
     def init(self, parent):
 
         self._parent = parent
-        self._parent.Bind(wx.EVT_SIZE, self._on_parent_size)
-
         self.ui_item.Create(parent, style=self._get_style())
 
         if self._font:
@@ -104,45 +115,49 @@ class Text(BaseWidget["wx.StaticText"]):
         if is_debugging():
             self.ui_item.SetBackgroundColour(GREEN)
         self._init()
+
+        if self._wrap:
+            self._parent.Bind(wx.EVT_SIZE, self._on_parent_size)
+            self._parent.Bind(wx.EVT_MAXIMIZE, self._on_parent_size)
+        else:
+            self.set_text(self._text)
         self._parent.PostSizeEvent()
 
     def __call__(self, parent):
         self.init(parent)
         return self
 
-    def _get_wrapped_text(self,text:str,width):
+    def _get_wrapped_text(self, text: str, width):
         client_item = wx.ClientDC(self._parent)
         client_item.Clear()
         client_item.SetFont(self._font)
 
-        txt = wordwrap(str(text),width,client_item)
+        txt = wordwrap(str(text), width, client_item)
         return txt
 
     def _on_parent_size(self, evt):
         evt.Skip()
 
         size = self.ui_item.Size
-        _LOGGER.debug("Text size changed %s",size)
-
+        _LOGGER.debug("TExt size %s", size)
         if size[0] == 0:
-            _LOGGER.debug("Not setting text.")
-            return
-        if self._previous_size[0] == size[0]:
-            return
-            # _LOGGER.debug("Previous size is the same skipping.")
+            _LOGGER.debug("Size is zero. Not setting text.")
 
-        self._previous_size = size
-        smaller_size = (size[0], -1)
-        self._set_text(client_size=smaller_size)
-        self._parent.Layout()
+        elif self._previous_size[0] == size[0]:
+            _LOGGER.debug("New size identical to previous size. skipping")
+
+        else:
+            self._previous_size = size
+            smaller_size = (size[0], -1)
+            self._set_text(client_size=smaller_size)
 
     def _set_text(self, color=None, client_size=None):
         if client_size and self._wrap:
-            txt = self._get_wrapped_text(self._text,client_size[0])
+            txt = self._get_wrapped_text(self._text, client_size[0])
         else:
-            txt=str(self._text)
+            txt = str(self._text)
         self.ui_item.SetLabel(txt)
-        self._parent.Refresh()
+        self.ui_item.GetParent().Layout()
 
     def set_text(self, text, color=None):
         """Set or change the text."""
